==> nextcloud-26.0.10.tgz: nextcloud/apps/federatedfilesharing/l10n/et_EE.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Soovid lisada kaugjagamise {name} asukohast {owner}@{remote}?",
    "Remote share" : "Kaugjagamine",
    "Remote share password" : "Kaugjagamise parool",
    "Cancel" : "Tühista",
    "Add remote share" : "Lisa kaugjagamine",
    "Invalid Federated Cloud ID" : "Vigane liitpilve ID",
    "Server to server sharing is not enabled on this server" : "Serveritevaheline jagamine ei ole selle pilves aktiiveeritud",
    "Couldn't establish a federated share." : "Liitjagamist ei õnnestunud luua",
    "Couldn't establish a federated share, maybe the password was wrong." : "Liitjagamist ei õnnestunud luua, ehk oli parool vale.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Liitjagamise päring edastatud, sulle saadetakse kutse. Kontrolli oma teateid.",
    "Not allowed to create a federated share with the same user" : "Liitjagamise loomine sama kasutajaga ei ole lubatud.",
    "File is already shared with %s" : "Fail on juba jagatud kasutajaga %s",
    "Could not find share" : "Jagamist ei leitud",
    "Federated sharing" : "Liit-jagamine",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Sa said kaugjagatud faili  {share} kasjutajalt  {user} ({behalf} nimel)",
    "You received {share} as a remote share from {user}" : "Sa said kaugjagatud faili {file} kasutajalt {user}",
    "Accept" : "Nõustu",
    "Decline" : "Keeldu",
    "Federated Cloud Sharing" : "Jagamine liitpilves",
    "Sharing" : "Jagamine",
    "Allow users on this server to receive shares from other servers" : "Luba selle serveri kasutajatel võtta vastu jagamisi teistest serveritest",
    "Search global and public address book for users" : "Otsi kasutajaid globaalsest ja avalikust aadressiraamatust",
    "Allow users to publish their data to a global and public address book" : "Luba kasutajatel avaldada oma andmeid globaalses ja avalikus aadressiraamatus",
    "Federated Cloud" : "Liitpilv",
    "Your Federated Cloud ID:" : "Sinu liitpilve ID:",
    "Share it so your friends can share files with you:" : "Jaga seda, et su sõbrad saaksid sinuga faile jagada:",
    "Twitter" : "Twitter",
    "Add to your website" : "Lisa oma veebisaidile",
    "Share with me via Nextcloud" : "Jaga minuga läbi Nextcloudi",
    "HTML Code:" : "HTML kood:",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Jaga minuga läbi minu #Nextcloudi liitpilve ID",
    "Copy to clipboard" : "Kopeeri lõikepuhvrisse",
    "Copied!" : "Kopeeritud!"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-27.1.7p0.tgz: nextcloud/apps/federatedfilesharing/l10n/et_EE.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Soovid lisada kaugjagamise {name} asukohast {owner}@{remote}?",
    "Remote share" : "Kaugjagamine",
    "Remote share password" : "Kaugjagamise parool",
    "Cancel" : "Tühista",
    "Add remote share" : "Lisa kaugjagamine",
    "Invalid Federated Cloud ID" : "Vigane liitpilve ID",
    "Server to server sharing is not enabled on this server" : "Serveritevaheline jagamine ei ole selle pilves aktiiveeritud",
    "Couldn't establish a federated share." : "Liitjagamist ei õnnestunud luua",
    "Couldn't establish a federated share, maybe the password was wrong." : "Liitjagamist ei õnnestunud luua, ehk oli parool vale.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Liitjagamise päring edastatud, sulle saadetakse kutse. Kontrolli oma teateid.",
    "File is already shared with %s" : "Fail on juba jagatud kasutajaga %s",
    "Could not find share" : "Jagamist ei leitud",
    "Federated sharing" : "Liit-jagamine",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Sa said kaugjagatud faili  {share} kasjutajalt  {user} ({behalf} nimel)",
    "You received {share} as a remote share from {user}" : "Sa said kaugjagatud faili {file} kasutajalt {user}",
    "Accept" : "Nõustu",
    "Decline" : "Keeldu",
    "Federated Cloud Sharing" : "Jagamine liitpilves",
    "Sharing" : "Jagamine",
    "Federated Cloud" : "Liitpilv",
    "Your Federated Cloud ID:" : "Sinu liitpilve ID:",
    "Share it so your friends can share files with you:" : "Jaga seda, et su sõbrad saaksid sinuga faile jagada:",
    "Twitter" : "Twitter",
    "Add to your website" : "Lisa oma veebisaidile",
    "Share with me via Nextcloud" : "Jaga minuga läbi Nextcloudi",
    "HTML Code:" : "HTML kood:",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Jaga minuga läbi minu #Nextcloudi liitpilve ID",
    "Copy to clipboard" : "Kopeeri lõikepuhvrisse",
    "Copied!" : "Kopeeritud!",
    "Not allowed to create a federated share with the same user" : "Liitjagamise loomine sama kasutajaga ei ole lubatud.",
    "Allow users on this server to receive shares from other servers" : "Luba selle serveri kasutajatel võtta vastu jagamisi teistest serveritest",
    "Search global and public address book for users" : "Otsi kasutajaid globaalsest ja avalikust aadressiraamatust",
    "Allow users to publish their data to a global and public address book" : "Luba kasutajatel avaldada oma andmeid globaalses ja avalikus aadressiraamatus"
},
"nplurals=2; plural=(n != 1);");
